#!/bin/sh

# Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# script for flashing SD card using dd
# the layout is:
#   * boot.img          -> 1st partition
#   * rootfs.img        -> 2nd partition
#   * systemd-data.img  -> 3rd partition
#   * modules.img       -> 6th partition
#
# script always checks for block device availability
# files are taken from CWD
# there are no checks if files exist, dd should fail
#
# SD card should be prepared using script mkpart.sh available at:
# https://wiki.tizen.org/wiki/Quick_guide_for_odroid#Fuse_bootloader_image
#
# Author: Aleksander Mistewicz <a.mistewicz@samsung.com>

TESTLAB_SCRIPTS="$(CDPATH='' cd -- "$(dirname -- "$0")"/.. && pwd -P)"

. "${TESTLAB_SCRIPTS}/common.sh"

test -n "${1}" || die "Too few arguments!"

sdd="sudo dd bs=4096"
test -b "${1}1" || die "No ${1}1"
$sdd if=boot.img "of=${1}1"
test -b "${1}2" || die "No ${1}2"
$sdd if=rootfs.img "of=${1}2"
test -b "${1}3" || die "No ${1}3"
$sdd if=system-data.img "of=${1}3"
test -b "${1}6" || die "No ${1}6"
$sdd if=modules.img "of=${1}6"
sync
